@@ -19,6 +19,62 @@ from graph_tool import all as gt
 
 ### ------------ ACCURACY PLOTS ------------ ###
 
+def plot_sklearn_summ_stats(summary_stats, VAL_DIR, fname = ""):
+    df = pd.melt(summary_stats, id_vars='gene')
+    df = df.astype({'variable':'string'})
+    q1 = df.groupby(df.variable).quantile(0.25)['value']
+    q3 = df.groupby(df.variable).quantile(0.75)['value']
+    outlier_top_lim = q3 + 1.5 * (q3 - q1)
+    outlier_bottom_lim = q1 - 1.5 * (q3 - q1)
+    plt.figure()
+    sns.boxplot(x="variable", y="value", data=pd.melt(summary_stats.drop('gene', axis = 1)))
+    col_dict = {i:j for i,j in zip(summary_stats.drop('gene', axis = 1).columns,range(len(summary_stats.columns)-1))}
+    for row in df.itertuples():
+        variable = row.variable
+        val = row.value
+        if (val > outlier_top_lim[variable]) or (val < outlier_bottom_lim[variable]):
+            print(val, row.gene)
+            plt.annotate(s = row.gene, xy = (col_dict[variable]+0.1,val), fontsize = 8)
+    plt.xticks(rotation = 45, ha = 'right')
+    plt.xlabel("Model Metric")
+    plt.ylabel("Score")
+    plt.title("Metrics for BooleaBayes Rule Fitting across All TFs")
+    plt.tight_layout()
+    plt.savefig(f"{VAL_DIR}/summary_stats_boxplot{fname}.pdf")
+    
+def plot_sklearn_metrics(VAL_DIR, show = False, save = True):
+    try:
+        summary_stats = pd.read_csv(f"{VAL_DIR}/summary_stats.csv", header = 0, index_col=0)
+    except FileNotFoundError:
+        print("You must run tl.get_sklearn_metrics first.")
+    if save:
+        try:
+            os.mkdir(f"{VAL_DIR}/summary_plots")
+        except FileExistsError:
+            pass
+    metric_dict = {'accuracy':{"Best":'1', "Worst":'0'},
+                   'balanced_accuracy_score':{"Best":'1', "Worst":'0'},
+                   'f1':{"Best":'1', "Worst":'0'},
+                   'roc_auc_score':{"Best":'1', "Worst":'0'},
+                   "precision":{"Best":'1', "Worst":'0'},
+                   "recall":{"Best":'1', "Worst":'0'},
+                   "explained_variance":{"Best":'1', "Worst":'0'},
+                   'max_error':{"Best":'0', "Worst":"High"},
+                   'r2':{"Best":'1', "Worst":'0'},
+                   'log-loss':{"Best":"Low", "Worst":"High"}}
+    for c in sorted(list(set(summary_stats.columns).difference({'gene'}))):
+        print(c)
+        plt.figure(figsize = (20,8))
+        my_order = summary_stats.sort_values(c)['gene'].values
+        sns.barplot(data = summary_stats, x = 'gene', y = c, order = my_order)
+        plt.xticks(rotation = 90, fontsize = 8)
+        plt.ylabel(f"{c.capitalize()} (Best: {metric_dict[c]['Best']}, Worst: {metric_dict[c]['Worst']})")
+        plt.title(c.capitalize())
+        if show:
+            plt.show()
+        if save:
+            plt.savefig(f"{VAL_DIR}/summary_plots/{c}.pdf")
+            plt.close()
 
 def plot_roc(
     fprs, tprs, area, node, save=False, save_dir=None,  show_plot=True
@@ -724,21 +780,24 @@ def plot_stability(attractor_dict, walks_dir, palette = sns.color_palette("tab20
             for i,r in norm.iterrows():
                 norm_df.loc[norm_df['radius']==i,'mean'] = norm_df.loc[norm_df['radius']==i,'mean']/r["mean"]
             norm_df = norm_df.sort_values(by = "cluster")
+            plt.figure()
             sns.lineplot(x = 'radius',y = 'mean',err_style=err_style,hue = 'cluster', palette=colormap,
                          data = norm_df, markers = True)
             plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left', borderaxespad=0, title = "Attractor Subtypes")
 
             plt.xticks(list(np.unique(norm_df['radius'])))
             plt.xlabel("Radius of Basin")
-            plt.ylabel("Scaled mean number of steps to leave basin (Fold-change from control mean)")
+            plt.ylabel(f"Scaled Mean number of steps to leave basin \n (Fold-change from control mean)")
             plt.title("Scaled Stability of Attractors by Subtype")
             plt.tight_layout()
             if show:
                 plt.show()
             if save:
                 plt.savefig(f"{walks_dir}/scaled_stability_plot.pdf")
+                plt.close()
 
     df = df.sort_values(by = "cluster")
+    plt.figure()
     sns.lineplot(x = 'radius',y = 'mean',err_style=err_style,hue = 'cluster', palette=colormap,
                       data = df, markers = True)
     plt.legend(bbox_to_anchor=(1.05, 1), loc='upper left', borderaxespad=0, title = "Attractor Subtypes")
@@ -752,6 +811,8 @@ def plot_stability(attractor_dict, walks_dir, palette = sns.color_palette("tab20
         plt.show()
     if save:
         plt.savefig(f"{walks_dir}/stability_plot.pdf")
+        plt.close()
+    return df
 
 # att_list = list of attractor states
 # phenotypes = list of phenotypes
